@@ -1,12 +1,11 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2002-2009                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef CMD_CREATE_STATEDIAG_H
@@ -14,8 +13,8 @@
 
 #include <QtGui/QUndoCommand>
 
-#include "umldoc.h"
-#include "umlview.h"
+class UMLDoc;
+class UMLView;
 
 namespace Uml
 {
