@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -866,7 +866,7 @@ void ListPopupMenu::insertAssocItem(const QString &label, Menu_Type mt)
  */
 void ListPopupMenu::insertSubmodelAction()
 {
-    const Settings::OptionState& ostat = Settings::getOptionState();
+    const Settings::OptionState& ostat = Settings::optionState();
     if (ostat.generalState.tabdiagrams) {
         // Umbrello currently does not support External Folders
         // in combination with Tabbed Diagrams.
