@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2010                                                *
+ *  copyright (C) 2002-2011                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -31,8 +31,6 @@
 #include "classifierlistitem.h"
 #include "object_factory.h"
 #include "import_rose.h"
-#include "model_utils.h"
-#include "widget_utils.h"
 #include "uml.h"
 #include "umllistview.h"
 #include "umllistviewitem.h"
@@ -44,10 +42,13 @@
 #include "listpopupmenu.h"
 #include "cmds.h"
 #include "diagramprintpage.h"
+// utils
+#include "debug_utils.h"
+#include "model_utils.h"
+#include "widget_utils.h"
 
 // kde includes
 #include <kdeversion.h>
-#include <kdebug.h>
 #include <kio/job.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
@@ -98,6 +99,7 @@ UMLDoc::UMLDoc()
     m_pCurrentRoot(0),
     m_bClosing(false)
 {
+    DEBUG_REGISTER(DBG_SRC);
 }
 
 /**
@@ -366,7 +368,7 @@ bool UMLDoc::newDocument()
     UMLApp::app()->setCurrentView(0);
     m_doc_url.setFileName(i18n("Untitled"));
     //see if we need to start with a new diagram
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     Uml::Diagram_Type dt = optionState.generalState.diagram;
     Uml::Model_Type mt = Model_Utils::convert_DT_MT(dt);
     if (mt == Uml::N_MODELTYPES) {  // don't allow no diagram
@@ -856,14 +858,14 @@ bool UMLDoc::addUMLObject(UMLObject* object)
     Object_Type ot = object->baseType();
     if (ot == ot_Attribute || ot == ot_Operation || ot == ot_EnumLiteral
             || ot == ot_EntityAttribute || ot == ot_Template || ot == ot_Stereotype) {
-        uDebug() << object->name() << ": not adding type " << ot;
+        DEBUG(DBG_SRC) << object->name() << ": not adding type " << ot;
         return false;
     }
     UMLPackage *pkg = object->umlPackage();
     if (pkg == 0) {
         pkg = currentRoot();
-        uDebug() << object->name() << ": no parent package set, assuming "
-                 << pkg->name();
+        DEBUG(DBG_SRC) << object->name() << ": no parent package set, assuming "
+                       << pkg->name();
         object->setUMLPackage( pkg );
     }
 
@@ -1116,7 +1118,7 @@ void UMLDoc::addAssociation(UMLAssociation *assoc)
         // check if its already been added (shouldn't be the case right now
         // as UMLAssociations only belong to one associationwidget at a time)
         if (a == assoc) {
-            uDebug() << "duplicate addition attempted";
+            DEBUG(DBG_SRC) << "duplicate addition attempted";
             return;
         }
     }
@@ -1241,7 +1243,7 @@ UMLView* UMLDoc::createDiagram(UMLFolder *folder, Uml::Diagram_Type type, bool a
             KMessageBox::error(0, i18n("That is an invalid name for a diagram."), i18n("Invalid Name"));
         } else if (!findView(type, name)) {
             UMLView* view = new UMLView(folder);
-            view->setOptionState( Settings::getOptionState() );
+            view->setOptionState( Settings::optionState() );
             view->setName( name );
             view->setType( type );
             view->setID( UniqueID::gen() );
@@ -1332,7 +1334,7 @@ void UMLDoc::renameChildUMLObject(UMLObject *o)
     bool ok = false;
     UMLClassifier* p = dynamic_cast<UMLClassifier *>(o->parent());
     if (!p) {
-        uDebug() << "Can not create object, no parent found.";
+        DEBUG(DBG_SRC) << "Can not create object, no parent found.";
         return;
     }
 
@@ -1367,7 +1369,7 @@ void UMLDoc::renameChildUMLObject(UMLObject *o)
  */
 void UMLDoc::changeCurrentView(Uml::IDType id)
 {
-    uDebug() << "id=" << ID2STR(id);
+    DEBUG(DBG_SRC) << "id=" << ID2STR(id);
     UMLApp* pApp = UMLApp::app();
     UMLView* view = findView(id);
     if (view) {
@@ -1831,7 +1833,7 @@ bool UMLDoc::loadFromXMI( QIODevice & file, short encode )
         }
         QDomElement element = node.toElement();
         if (element.isNull()) {
-            uDebug() << "loadFromXMI: skip empty elem";
+            DEBUG(DBG_SRC) << "loadFromXMI: skip empty elem";
             continue;
         }
         bool recognized = false;
@@ -1853,7 +1855,7 @@ bool UMLDoc::loadFromXMI( QIODevice & file, short encode )
         }
         if (outerTag != "XMI.content" ) {
             if (!recognized) {
-                uDebug() << "skipping <" << outerTag << ">";
+                DEBUG(DBG_SRC) << "skipping <" << outerTag << ">";
             }
             continue;
         }
@@ -1892,7 +1894,7 @@ bool UMLDoc::loadFromXMI( QIODevice & file, short encode )
                 // This tag is produced here, i.e. outside of <UML:Model>,
                 // by the Unisys.JCR.1 Rose-to-XMI tool.
                 if (! seen_UMLObjects) {
-                    uDebug() << "skipping TaggedValue because not seen_UMLObjects";
+                    DEBUG(DBG_SRC) << "skipping TaggedValue because not seen_UMLObjects";
                     continue;
                 }
                 tag = element.attribute("tag", "");
@@ -1901,14 +1903,14 @@ bool UMLDoc::loadFromXMI( QIODevice & file, short encode )
                 }
                 QString modelElement = element.attribute("modelElement", "");
                 if (modelElement.isEmpty()) {
-                    uDebug() << "skipping TaggedValue(documentation) because "
-                             << "modelElement.isEmpty()";
+                    DEBUG(DBG_SRC) << "skipping TaggedValue(documentation) because "
+                                   << "modelElement.isEmpty()";
                     continue;
                 }
                 UMLObject *o = findObjectById(STR2ID(modelElement));
                 if (o == 0) {
-                    uDebug() << "TaggedValue(documentation): cannot find object"
-                             << " for modelElement " << modelElement;
+                    DEBUG(DBG_SRC) << "TaggedValue(documentation): cannot find object"
+                                   << " for modelElement " << modelElement;
                     continue;
                 }
                 QString value = element.attribute("value", "");
@@ -1922,7 +1924,7 @@ bool UMLDoc::loadFromXMI( QIODevice & file, short encode )
         }
     }
 #ifdef VERBOSE_DEBUGGING
-    uDebug() << "m_objectList.count() is " << m_objectList.count();
+    DEBUG(DBG_SRC) << "m_objectList.count() is " << m_objectList.count();
 #endif
     resolveTypes();
     // set a default code generator if no <XMI.extensions><codegeneration> tag seen
@@ -1962,8 +1964,8 @@ void UMLDoc::resolveTypes()
     for (int i = 0; i < Uml::N_MODELTYPES; ++i) {
        UMLFolder *obj = m_root[i];
 #ifdef VERBOSE_DEBUGGING
-        uDebug() << "UMLDoc: invoking resolveRef() for " << obj->getName()
-            << " (id=" << ID2STR(obj->getID()) << ")";
+        DEBUG(DBG_SRC) << "UMLDoc: invoking resolveRef() for " << obj->getName()
+                       << " (id=" << ID2STR(obj->getID()) << ")";
 #endif
         obj->resolveRef();
     }
@@ -2053,8 +2055,8 @@ bool UMLDoc::loadUMLObjectsFromXMI(QDomElement& element)
         if (! tempElement.hasAttribute("xmi.id")) {
             QString idref = tempElement.attribute("xmi.idref", "");
             if (! idref.isEmpty()) {
-                uDebug() << "resolution of xmi.idref " << idref
-                         << " is not yet implemented";
+                DEBUG(DBG_SRC) << "resolution of xmi.idref " << idref
+                               << " is not yet implemented";
             } else {
                 uError() << "Cannot load " << type
                          << " because xmi.id is missing";
@@ -2099,10 +2101,10 @@ bool UMLDoc::loadUMLObjectsFromXMI(QDomElement& element)
                 if (exist->id() == pObject->id()) {
                     delete pObject;
                 } else {
-                    uDebug() << "Stereotype " << pObject->name()
-                             << "(id=" << ID2STR(pObject->id())
-                             << ") already exists with id="
-                             << ID2STR(exist->id());
+                    DEBUG(DBG_SRC) << "Stereotype " << pObject->name()
+                                   << "(id=" << ID2STR(pObject->id())
+                                   << ") already exists with id="
+                                   << ID2STR(exist->id());
                     addStereotype(s);
                 }
             } else {
@@ -2212,7 +2214,7 @@ bool UMLDoc::loadDiagramsFromXMI( QDomNode & node )
     if ( element.isNull() ) {
         return true;  //return ok as it means there is no umlobjects
     }
-    const Settings::OptionState state = Settings::getOptionState();
+    const Settings::OptionState state = Settings::optionState();
     UMLView * pView = 0;
     int count = 0;
     while ( !element.isNull() ) {
@@ -2468,7 +2470,7 @@ bool UMLDoc::isModified()
 bool UMLDoc::assignNewIDs(UMLObject* obj)
 {
     if (!obj || !m_pChangeLog) {
-        uDebug() << "no obj || Changelog";
+        DEBUG(DBG_SRC) << "no obj || Changelog";
         return false;
     }
     Uml::IDType result = assignNewID(obj->id());
@@ -2632,7 +2634,7 @@ bool UMLDoc::addUMLView(UMLView * pView )
 
     pView->activateAfterLoad( true );
     pView->endPartialWidgetPaste();
-    pView->setOptionState( Settings::getOptionState() );
+    pView->setOptionState( Settings::optionState() );
     addView(pView);
     setModified(true);
     return true;
@@ -2677,7 +2679,7 @@ void UMLDoc::initSaveTimer()
         delete m_pAutoSaveTimer;
         m_pAutoSaveTimer = 0;
     }
-    Settings::OptionState optionState = Settings::getOptionState();
+    Settings::OptionState optionState = Settings::optionState();
     if ( optionState.generalState.autosave ) {
         m_pAutoSaveTimer = new QTimer(this);
         connect( m_pAutoSaveTimer, SIGNAL( timeout() ), this, SLOT( slotAutoSave() ) );
@@ -2709,7 +2711,7 @@ void UMLDoc::slotAutoSave()
         QString orgFileName = m_doc_url.fileName();
         // don't overwrite manually saved file with autosave content
         QString fileName = tempUrl.fileName();
-        Settings::OptionState optionState = Settings::getOptionState();
+        Settings::OptionState optionState = Settings::optionState();
         fileName.replace( ".xmi", optionState.generalState.autosavesuffix );
         tempUrl.setFileName( fileName );
         // End Achim Spangler
@@ -2737,7 +2739,7 @@ void UMLDoc::slotAutoSave()
 void UMLDoc::signalDiagramRenamed(UMLView* view)
 {
     if (view) {
-        Settings::OptionState optionState = Settings::getOptionState();
+        Settings::OptionState optionState = Settings::optionState();
         if (optionState.generalState.tabdiagrams) {
             UMLApp::app()->tabWidget()->setTabText( UMLApp::app()->tabWidget()->indexOf(view), view->getName() );
         }
@@ -2755,7 +2757,7 @@ void UMLDoc::addDefaultDatatypes()
 {
     CodeGenerator *cg = UMLApp::app()->generator();
     if (cg == 0) {
-        uDebug() << "CodeGenerator is still NULL";
+        DEBUG(DBG_SRC) << "CodeGenerator is still NULL";
         return;
     }
     QStringList entries = cg->defaultDatatypes();
@@ -2835,7 +2837,7 @@ void UMLDoc::slotDiagramPopupMenu(QWidget* umlview, const QPoint& point)
         return;
     }//end switch
 
-    // uDebug() << "create popup for ListView_Type " << type;
+    // DEBUG(DBG_SRC) << "create popup for ListView_Type " << type;
     m_pTabPopupMenu = new ListPopupMenu(UMLApp::app()->mainViewWidget(), type, 0);
     m_pTabPopupMenu->popup(point);
     connect(m_pTabPopupMenu, SIGNAL(triggered(QAction*)), view, SLOT(slotMenuSelection(QAction*)));
