@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2010                                               *
+ *   copyright (C) 2002-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -122,7 +122,7 @@ UMLWidget& UMLWidget::operator=(const UMLWidget & other)
     return *this;
 }
 
-bool UMLWidget::operator==(const UMLWidget& other)
+bool UMLWidget::operator==(const UMLWidget& other) const
 {
     if (this == &other)
         return true;
@@ -359,7 +359,7 @@ void UMLWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Change_Font:
     case ListPopupMenu::mt_Change_Font_Selection: {
         QFont font = UMLWidget::font();
-        if (KFontDialog::getFont(font, false, m_pView)) {
+        if (KFontDialog::getFont(font, KFontChooser::NoDisplayFlags, m_pView)) {
             UMLApp::app()->executeCommand(new CmdChangeFontSelection(m_pDoc, m_pView, font));
         }
     }
